/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.s3.bridge;

import org.apache.atlas.model.instance.AtlasObjectId;
import org.apache.atlas.s3.bridge.models.AtlasAwsS3Entity;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class AtlasAwsS3DeleteEvent extends AtlasAwsS3Event {
    private static final String PROPERTY_QUALIFIED_NAME = "qualifiedName";
    private List<AtlasObjectId> deletedObjectId         = new ArrayList<>();

    public AtlasAwsS3DeleteEvent(AtlasAwsS3Entity atlasAwsS3Entity) {
        super(AtlasAwsS3EventType.DELETE);

        String qualifiedName = atlasAwsS3Entity.getQualifiedName();

        deletedObjectId.add(new AtlasObjectId(atlasAwsS3Entity.getAtlasEntity().getTypeName(), Collections.singletonMap(PROPERTY_QUALIFIED_NAME, qualifiedName)));
    }

    public List<AtlasObjectId> getObjectIdsForDeletion() {
        return deletedObjectId;
    }
}
