/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.s3.bridge;

import com.fasterxml.jackson.databind.node.ObjectNode;
import com.sun.jersey.api.client.WebResource;
import org.apache.atlas.AtlasBaseClient;
import org.apache.atlas.AtlasException;
import org.apache.atlas.exception.AtlasBaseException;
import org.apache.atlas.s3.bridge.models.Credentials;
import org.apache.atlas.s3.bridge.models.IDBrokerCredentialResponse;
import org.apache.atlas.type.AtlasType;
import java.io.Serializable;

public class AtlasIDBrokerClient extends AtlasBaseClient implements Serializable {
    private static final long serialVersionUID = 1L;

    public AtlasIDBrokerClient(String... baseUrls) throws AtlasException {
        super(baseUrls);
    }

    public WebResource getResource() {
        return service;
    }

    @Override
    protected API formatPathParameters(final API api, final String... params) {
        return new API(String.format(api.getPath(), params), api.getMethod(), api.getExpectedStatus());
    }

    public Credentials getAwsS3Credential(API getAwsS3CredentialAPI) throws AtlasBaseException {
        try {
            WebResource                resource                   = getResource(getAwsS3CredentialAPI);
            ObjectNode                 objectNode                 = callAPIWithResource(getAwsS3CredentialAPI, resource, null, ObjectNode.class);
            IDBrokerCredentialResponse idBrokerCredentialResponse = AtlasType.fromJson(objectNode.toString(), IDBrokerCredentialResponse.class);

            if (idBrokerCredentialResponse != null) {
                return idBrokerCredentialResponse.getCredentials();
            }
        } catch (Exception e) {
            throw new AtlasBaseException("Exception occurred while fetching AWS Credential: " + e.getMessage(), e);
        }

        throw new AtlasBaseException("Empty response from IDBroker for Aws S3 Credential.");
    }
}