/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.s3.bridge.models;

import org.apache.atlas.model.instance.AtlasEntity;
import org.apache.atlas.model.instance.AtlasStruct;
import org.apache.commons.collections.CollectionUtils;
import software.amazon.awssdk.services.s3.model.Tag;

import java.util.ArrayList;
import java.util.List;

public interface AtlasAwsS3Entity {
    String SCHEME_SEPARATOR                    = "://";
    String AWS_TAG_TYPE                        = "awsTags";
    String DEFAULT_METADATA_NAMESPACE          = "primary";
    char   QNAME_SEP_METADATA_NAMESPACE        = '@';

    String PROPERTY_TAG_KEY                    = "key";
    String PROPERTY_TAG_VALUE                  = "value";
    String PROPERTY_ENCRYPTION                 = "encryption";
    String PROPERTY_AWS_TAG                    = "awsTags";
    String PROPERTY_REGION                     = "region";
    String PROPERTY_NAME                       = "name";
    String PROPERTY_OWNER_ID                   = "ownerId";
    String PROPERTY_OWNER_NAME                 = "ownerName";
    String PROPERTY_QUALIFIED_NAME             = "qualifiedName";

    String name();

    AtlasEntity getAtlasEntity();

    AtlasEntity.AtlasEntitiesWithExtInfo getAtlasEntitiesWithExtInfo();

    String getQualifiedName();

    default List<AtlasStruct> convertToAtlasAwsTags(List<Tag> tags) {
        List<AtlasStruct> awsTags = null;
        if(CollectionUtils.isNotEmpty(tags)) {
            awsTags = new ArrayList<>(tags.size());

            for (Tag tag : tags) {
                AtlasStruct atlasAwsTag = new AtlasStruct(AWS_TAG_TYPE);

                atlasAwsTag.setAttribute(PROPERTY_TAG_KEY, tag.key());
                atlasAwsTag.setAttribute(PROPERTY_TAG_VALUE, tag.value());

                awsTags.add(atlasAwsTag);
            }
        }

        return awsTags;
    }
}
