/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.s3.extractors;

import org.apache.atlas.exception.AtlasBaseException;
import org.slf4j.Logger;
import software.amazon.awssdk.core.exception.SdkException;
import software.amazon.awssdk.services.s3.model.S3Exception;

public class AwsExceptionHandler {
    //Return false If the exception is not retryable
    public static boolean handleException(SdkException e, AwsClient awsClient, Logger LOG, String errorMsg) throws AtlasBaseException {
        boolean ret = true;

        if (isAwsS3ExpiredTokenException(e)) {
            LOG.info("Aws token has expired.");

            awsClient.reinitialize();
        } else {
            if (!e.retryable()) {
                ret = false;
            }

            if (LOG.isDebugEnabled()) {
                String formattedMsg = errorMsg + ": " + e.getMessage();
                LOG.debug(formattedMsg, e);
            } else {
                LOG.warn(errorMsg);
            }
        }

        return ret;
    }

    public static boolean isAwsS3ExpiredTokenException(SdkException e) {
        return (e instanceof S3Exception && isAwsS3ExpiredTokenException((S3Exception) e));
    }

    private static boolean isAwsS3ExpiredTokenException(S3Exception e) {
        return e.awsErrorDetails().errorCode().equalsIgnoreCase(Constants.AWS_S3_EXPIRED_TOKEN_EXCEPTION_ERROR);
    }
}
