/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.s3.extractors.incremental.models;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonSerialize(include=JsonSerialize.Inclusion.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
@XmlRootElement
@XmlAccessorType(XmlAccessType.PROPERTY)
public class Record {
    @JsonProperty("eventVersion")
    private String eventVersion;

    @JsonProperty("eventSource")
    private String eventSource;

    @JsonProperty("awsRegion")
    private String awsRegion;

    @JsonProperty("eventTime")
    private String eventTime;

    @JsonProperty("eventName")
    private String eventName;

    @JsonProperty("userIdentity")
    private OwnerIdentity ownerIdentity;

    @JsonProperty("s3")
    private S3Body s3Body;

    public S3Body getS3Body() {
        return s3Body;
    }

    public void setS3Body(S3Body s3Body) {
        this.s3Body = s3Body;
    }

    public String getEventVersion() {
        return eventVersion;
    }

    public void setEventVersion(String eventVersion) {
        this.eventVersion = eventVersion;
    }

    public String getEventSource() {
        return eventSource;
    }

    public void setEventSource(String eventSource) {
        this.eventSource = eventSource;
    }

    public String getAwsRegion() {
        return awsRegion;
    }

    public void setAwsRegion(String awsRegion) {
        this.awsRegion = awsRegion;
    }

    public String getEventTime() {
        return eventTime;
    }

    public void setEventTime(String eventTime) {
        this.eventTime = eventTime;
    }

    public String getEventName() {
        return eventName;
    }

    public void setEventName(String eventName) {
        this.eventName = eventName;
    }

    public OwnerIdentity getOwnerIdentity() {
        return ownerIdentity;
    }

    public void setOwnerIdentity(OwnerIdentity ownerIdentity) {
        this.ownerIdentity = ownerIdentity;
    }

    @Override
    public String toString() {
        return "Record{" +
                "eventVersion='" + eventVersion + '\'' +
                ", eventSource='" + eventSource + '\'' +
                ", awsRegion='" + awsRegion + '\'' +
                ", eventTime='" + eventTime + '\'' +
                ", eventName='" + eventName + '\'' +
                ", userIdentity=" + ownerIdentity +
                ", s3=" + s3Body +
                '}';
    }
}
