/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.adls.bridge;

import org.apache.atlas.adls.bridge.models.AtlasADLSEntity;
import org.apache.atlas.model.instance.AtlasEntity;
import org.apache.atlas.model.instance.AtlasObjectId;

import java.util.Collections;

public class AtlasADLSPartialUpdateEvent extends AtlasADLSEvent {
    private static final String PROPERTY_QUALIFIED_NAME = "qualifiedName";

    private final AtlasEntity.AtlasEntityWithExtInfo entityExtInfo;
    private final AtlasObjectId                      oldTableId;

    public AtlasADLSPartialUpdateEvent(AtlasADLSEntity oldAtlasADLSEntity, AtlasADLSEntity newAtlasADLSEntity) {
        super(AtlasADLSEventType.PARTIAL_UPDATE);

        // make a copy of renamedTableEntity to send as partial-update with no relationship attributes
        AtlasEntity renamedEntityForPartialUpdate = new AtlasEntity(newAtlasADLSEntity.getEntity());

        renamedEntityForPartialUpdate.setRelationshipAttributes(null);

        this.entityExtInfo = new AtlasEntity.AtlasEntityWithExtInfo(renamedEntityForPartialUpdate);

        String qualifiedName = oldAtlasADLSEntity.getQualifiedName();

        this.oldTableId = new AtlasObjectId(oldAtlasADLSEntity.getEntity().getTypeName(), Collections.singletonMap(PROPERTY_QUALIFIED_NAME, qualifiedName));
    }

    public AtlasObjectId getOldObjectId() {
        return oldTableId;
    }

    public AtlasEntity.AtlasEntityWithExtInfo getEntityExtInfo() {
        return entityExtInfo;
    }
}