/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.adls.extractors;

import java.time.Duration;

public class Constants {
    public static final String PROPERTY_EXTRACTION_START_TIME_AT_PROGRESS_FILE = "EXTRACTION_START_TIME";
    public static final String DEFAULT_PREFIX_DELIMITER                        = "/";
    public static final String DEFAULT_ADLS_GEN2_ACCOUNT_HOST_SUFFIX           = ".dfs.core.windows.net";
    public static final String DEFAULT_CONTAINER_ACCOUNT_DELIMITER             = "@";
    public static final String DEFAULT_SUBJECT_PREFIX                          = "/blobServices/default/containers/";
    public static final String DEFAULT_SUBJECT_BLOB_NAME_SEPARATOR             = "/blobs/";
    public static final String IS_DIRECTORY_METADATA_KEY                       = "hdi_isfolder";
    public static final String EVENT_DATA_SOURCE_URL                           = "sourceUrl";

    public static final int    DEFAULT_QUEUE_MAX_MESSAGES_PER_REQUEST          = 10;
    public static final int    MIN_FOR_QUEUE_MAX_MESSAGES_PER_REQUEST          = 1;
    public static final int    MAX_FOR_QUEUE_MAX_MESSAGES_PER_REQUEST          = 32;
    public static final int    DEFAULT_QUEUE_REQUEST_WAIT_TIME                 = 50;
    public static final int    DEFAULT_MAX_RETRY                               = 20;
    public static final int    DEFAULT_QUEUE_VISIBILITY_TIMEOUT                = 60;

    public static final char   CONFIG_PATH_SEPARATOR                           = ',';
    public static final char   CONFIG_ACCOUNT_QUEUE_SEPARATOR                  = ':';

    static final String        ADLS_EXTRACTION_CONFIG_PREFIX                   = "atlas.adls.extraction.";
    static final String        INCREMENTAL_EXTRACTION_CONFIG_PREFIX            = ADLS_EXTRACTION_CONFIG_PREFIX + "incremental.";

    //Queue related
    public static final String CONFIG_QUEUE_NAMES                              = INCREMENTAL_EXTRACTION_CONFIG_PREFIX + "queueNames";
    public static final String CONFIG_QUEUE_MAX_MESSAGES_PER_REQUEST           = INCREMENTAL_EXTRACTION_CONFIG_PREFIX + "messagesPerRequest";
    public static final String CONFIG_QUEUE_REQUEST_WAIT_TIME                  = INCREMENTAL_EXTRACTION_CONFIG_PREFIX + "requestWaitTime";
    public static final String CONFIG_MAX_RETRY                                = INCREMENTAL_EXTRACTION_CONFIG_PREFIX + "max.retry";
    public static final String CONFIG_QUEUE_VISIBILITY_TIMEOUT                 = INCREMENTAL_EXTRACTION_CONFIG_PREFIX + "visibility.timeout";
    public static final String CONFIG_DELETE_NEEDED_FOR_RENAME                 = INCREMENTAL_EXTRACTION_CONFIG_PREFIX + "delete.needed.for.rename";
    public static final String FILE_SYSTEM_SCHEME_FOR_ID_BROKER                = "azure";

    static final String        DEFAULT_ADLS_EXTRACTOR_PROGRESS_FILE            = "adls_extractor_progress_file.prop";
    static final String        DEFAULT_FILE_SYSTEM_SCHEME                      = "abfs";
    static final int           DEFAULT_MAX_NUMBER_OF_BLOB_PER_CALL             = 1000;
    static final int           DEFAULT_MAX_RECONNECT_COUNT                     = 2;
    static final boolean       DEFAULT_RESUME_FROM_PROGRESS_FILE               = false;
    static final boolean       DEFAULT_DELETE_NEEDED_FOR_RENAME                = false;
    static final Duration      DEFAULT_TIMEOUT_DURATION_IN_SEC                 = Duration.ofSeconds(30);

    static final String        CONFIG_MAX_RECONNECT_COUNT                      = ADLS_EXTRACTION_CONFIG_PREFIX + "max.reconnect.count";
    static final String        CONFIG_ADLS_FILE_SYSTEM                         = ADLS_EXTRACTION_CONFIG_PREFIX + "fs.system";
    static final String        CONFIG_BLACKLIST_PATHS                          = ADLS_EXTRACTION_CONFIG_PREFIX + "denylist.paths";
    static final String        CONFIG_WHITELIST_PATHS                          = ADLS_EXTRACTION_CONFIG_PREFIX + "allowlist.paths";
    static final String        CONFIG_ACCESS_TOKEN                             = ADLS_EXTRACTION_CONFIG_PREFIX + "access.token";
    static final String        CONFIG_ACCESS_TOKEN_EXPIRES_AT                  = ADLS_EXTRACTION_CONFIG_PREFIX + "access.token.expires.at";
    static final String        CONFIG_ACCOUNT_KEY                              = ADLS_EXTRACTION_CONFIG_PREFIX + "account.key";
    static final String        CONFIG_ACCOUNT_NAME                             = ADLS_EXTRACTION_CONFIG_PREFIX + "account.name";
    static final String        CONFIG_RESUME_FROM_PROGRESS_FILE                = ADLS_EXTRACTION_CONFIG_PREFIX + "resume.from.progress.file";
    static final String        CONFIG_EXTRACTOR_PROGRESS_FILE                  = ADLS_EXTRACTION_CONFIG_PREFIX + "progress.file";
    static final String        CONFIG_PREFIX_DELIMITER                         = ADLS_EXTRACTION_CONFIG_PREFIX + "prefix.delimiter";
    static final String        CONFIG_EXTRACTOR_MAX_BLOB_PER_CALL              = ADLS_EXTRACTION_CONFIG_PREFIX + "max.blob.per.call";
    static final String        CONFIG_TIMEOUT_PER_CALL_IN_SEC                  = ADLS_EXTRACTION_CONFIG_PREFIX + "timeout.per.call.in.sec";

    static final String        BLOB_SERVICE_URL_ENDPOINT_FORMAT                = "https://%s.blob.core.windows.net";
    static final String        QUEUE_SERVICE_URL_ENDPOINT_FORMAT               = "https://%s.queue.core.windows.net";
    static final String        CORE_SITE_PROPERTIES                            = "core-site.xml";
    static final String        ATLAS_LOG_DIR                                   = "atlas.log.dir";

    static final String        FAIL_ON_ERROR_FLAG                              = "failOnErrorFlag";
}