/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.hdfs.lineage;

import org.apache.atlas.exception.AtlasBaseException;
import org.apache.atlas.hdfs.cli.CliContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;

public class HDFSLineageTask implements LineageTask {
    private static final Logger LOG = LoggerFactory.getLogger(HDFSLineageTask.class);
    private static final String TASK_NAME = "HDFS Lineage";

    private final HDFSLineageContext lineageContext;
    private final HDFSEventHandler hdfsEventHandler;

    public HDFSLineageTask(CliContext cliContext) throws AtlasBaseException {
        this.lineageContext = new HDFSLineageContext(cliContext);
        this.hdfsEventHandler = new HDFSEventHandler(lineageContext);
    }

    @Override
    public String getName() {
        return TASK_NAME;
    }

    @Override
    public void initialize() throws AtlasBaseException {
        lineageContext.initialize();
    }

    @Override
    public int execute(List<String> args) {
        int exitCode = Constants.EXIT_CODE_FAILED;
        LOG.info("Starting lineage creation for :  " + args);
        try {

            exitCode =  hdfsEventHandler.processEvent(args);

        } catch (Exception e) {
            LOG.error("Exception occurred while processing event for : {} : {}", args,  e.getMessage(), e);
        }

        LOG.info("Completed lineage creation for : " + args );
        return exitCode;
    }

    @Override
    public HDFSLineageContext getLineageContext() {
        return lineageContext;
    }

}