#!/bin/bash
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License. See accompanying LICENSE file.
#
# resolve links - $0 may be a softlink
PRG="${0}"

[[ `uname -s` == *"CYGWIN"* ]] && CYGWIN=true

while [ -h "${PRG}" ]; do
  ls=`ls -ld "${PRG}"`
  link=`expr "$ls" : '.*-> \(.*\)$'`
  if expr "$link" : '/.*' > /dev/null; then
    PRG="$link"
  else
    PRG=`dirname "${PRG}"`/"$link"
  fi
done

BASEDIR=`dirname ${PRG}`

if test -z "${JAVA_HOME}"
then
    JAVA_BIN=`which java`
    JAR_BIN=`which jar`
else
    JAVA_BIN="${JAVA_HOME}/bin/java"
    JAR_BIN="${JAVA_HOME}/bin/jar"
fi
export JAVA_BIN

if [ ! -e "${JAVA_BIN}" ] || [ ! -e "${JAR_BIN}" ]; then
  echo "$JAVA_BIN and/or $JAR_BIN not found on the system. Please make sure java and jar commands are available."
  exit 1
fi

# Construct ATLAS_CONF where atlas-properties reside
ATLAS_CONF=${BASEDIR}
ATLAS_OPTS="-Xms8g -Xmx64g -XX:SoftRefLRUPolicyMSPerMB=0 -XX:+CMSClassUnloadingEnabled -XX:+UseConcMarkSweepGC -XX:+CMSParallelRemarkEnabled -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=/tmp/nav2atlas-heap-dump.hprof"
# log dir for applications
ATLAS_BASE_DIR="${BASEDIR}/../../server/webapp/atlas/WEB-INF"
ATLAS_LOG_DIR="/var/log/atlas"
ATLAS_LOG_FILE="nav2atlas.log"
LOG_CONFIG="${BASEDIR}/atlas-nav2atlas-log4j.xml"

# Construct Atlas classpath.
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/slf4j-api*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/slf4j-log4j12*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/log4j-*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/commons-cli*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/commons-io*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/commons-lang-*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/commons-lang3*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/commons-configuration*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/commons-logging*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/commons-collections*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/guava-*.jar | head -n 1)"

ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/jackson-annotations-*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/jackson-core-*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/jackson-databind-*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/jackson-jaxrs-base-*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/jackson-jaxrs-json-provider-*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/jackson-module-jaxb-annotations-*.jar | head -n 1)"

ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/lz4*.jar | head -n 1)"

ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/curator-client-*.jar | head -n 1)"

ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/hadoop-common*.jar | head -n 1)"

ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/atlas-common*.jar | head -n 1)"
ATLASCPPATH="$ATLASCPPATH:$(ls ${ATLAS_BASE_DIR}/lib/atlas-intg*.jar | head -n 1)"

for i in "${BASEDIR}/"*.jar; do
  ATLASCPPATH="${ATLASCPPATH}:$i"
done

for i in "${BASEDIR}/"*.properties; do
  ATLASCPPATH="${ATLASCPPATH}:$i"
done

echo "Logging: ${ATLAS_LOG_DIR}/${ATLAS_LOG_FILE}"
echo "Log config: ${LOG_CONFIG}"

TIME=`date +%Y%m%d%H%M%s`
CP="${ATLASCPPATH}:${ATLAS_CONF}"

# If running in cygwin, convert pathnames and classpath to Windows format.
if [ "${CYGWIN}" == "true" ]
then
   ATLAS_LOG_DIR=`cygpath -w ${ATLAS_LOG_DIR}`
   ATLAS_LOG_FILE=`cygpath -w ${ATLAS_LOG_FILE}`
   CP=`cygpath -w -p ${CP}`
fi

JAVA_PROPERTIES="$ATLAS_OPTS -Datlas.conf=${ATLAS_CONF} -Datlas.log.dir=$ATLAS_LOG_DIR -Datlas.log.file=$ATLAS_LOG_FILE -Dlog4j.configuration=file://${LOG_CONFIG}"

echo "Nav2Atlas: Initiating..."

IMPORT_ARGS=$@
JVM_ARGS=
JAVA_PROPERTIES="${JAVA_PROPERTIES} ${JVM_ARGS}"
"${JAVA_BIN}" ${JAVA_PROPERTIES} -cp "${CP}" org.apache.atlas.tools.NavigatorBridge $IMPORT_ARGS

echo "Nav2Atlas: Done!"

RETVAL=$?
[ $RETVAL -eq 0 ] && echo Done!
[ $RETVAL -ne 0 ] && echo Failed!
exit $RETVAL

