/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.tools.models.MultiNodeContainer;
import org.apache.atlas.tools.models.Session;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Map;

public class AtlasEntityValidator {
    private static final Logger LOG = LoggerFactory.getLogger(AtlasEntityValidator.class);

    private AtlasTypeFactory atlasTypeFactory;

    public AtlasEntityValidator(AtlasTypeFactory atlasTypeFactory) {
        this.atlasTypeFactory = atlasTypeFactory;
    }

    public boolean isValid(String atlasType, MultiNodeContainer incomingEntity) {
        if (incomingEntity == null) {
            LOG.error("Entity was NULL!");
            return false;
        }

        boolean ret = false;
        MultiNodeContainer referenceEntity = atlasTypeFactory.create(atlasType);
        for (String key : referenceEntity.get().keySet()) {
            if (!incomingEntity.get().containsKey(key)) {
                LOG.error(String.format("Entity: %s", key));
                ret = false;
                continue;
            }

            if (referenceEntity.get(key) instanceof Map) {
                Map mapReference = (Map) referenceEntity.get(key);
                Map mapIncoming = (Map) incomingEntity.get(key);
                if (mapIncoming == null || !(mapIncoming instanceof Map)) {
                    LOG.error(String.format("Entity: %s", key));
                    ret = false;
                    continue;
                }

                ret = validateMapAttribute(mapReference, mapIncoming);
            } else {
                if (incomingEntity.get(key) == null) {
                    LOG.error(String.format("Entity: %s", key));
                    ret = false;
                    continue;
                }
            }
        }

        return ret;
    }

    private boolean validateMapAttribute(Map mapReference, Map mapIncoming) {
        boolean ret = true;
        for (Object o : mapReference.keySet()) {
            String key2 = (String) o;
            if (!mapIncoming.containsKey(key2)) {
                LOG.error(String.format("Entity: %s", key2));
                ret = false;
                continue;
            }
        }
        return ret;
    }
}
