/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.model.instance.AtlasEntity;
import org.apache.atlas.model.instance.AtlasRelationship;
import org.apache.atlas.tools.models.Conversion.Specs;
import org.apache.atlas.tools.models.Entity;
import org.apache.atlas.tools.models.JobSummary;
import org.apache.atlas.tools.models.Relation;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Set;

public interface EntityConverter {
    void addSpecs(Specs specs);
    List<AtlasEntity.AtlasEntityWithExtInfo> convert(Entity incomingEntity) throws ConversionException;
    void convert(Relation relation) throws ConversionException;
    void convert(InputStream inputStream, EntityRelationsWriter writer) throws IOException;
    boolean isValid(AtlasEntity.AtlasEntityWithExtInfo entityWithExtInfo);
    String getTypesDef();

    Set<String> getOrder();

    void clearValidationErrors();
    boolean hasConverter(Entity entity);

    JobSummary getJobSummary();
}
