/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.model.instance.AtlasEntity;
import org.apache.atlas.tools.models.Conversion.Specs;
import org.apache.atlas.tools.models.Entity;
import org.apache.atlas.tools.models.JobSummary;
import org.apache.atlas.tools.models.Relation;
import org.apache.atlas.tools.models.Session;
import org.apache.atlas.tools.pc.RelationsManager;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Set;

public class RelationsReadConvertWrite implements EntityConverter {
    private static final Logger LOG = LoggerFactory.getLogger(RelationsReadConvertWrite.class);

    private final Session session;
    private final JobSummary jobSummary;

    public RelationsReadConvertWrite(Session session) {
        this.session = session;
        jobSummary = new JobSummary();
    }

    public void convert(InputStream inputStream) throws IOException {
        RelationsReadConvertWrite.Reader converterReaderWriter = new RelationsReadConvertWrite.Reader();
        converterReaderWriter.read(inputStream);
    }

    @Override
    public void addSpecs(Specs specs) {

    }

    @Override
    public List<AtlasEntity.AtlasEntityWithExtInfo> convert(Entity incomingEntity) throws ConversionException {
        return null;
    }

    @Override
    public void convert(Relation relation) throws ConversionException {

    }

    @Override
    public void convert(InputStream inputStream, EntityRelationsWriter writer) throws IOException {

    }

    @Override
    public boolean isValid(AtlasEntity.AtlasEntityWithExtInfo entityWithExtInfo) {
        return true;
    }

    @Override
    public String getTypesDef() {
        return null;
    }

    @Override
    public Set<String> getOrder() {
        return null;
    }

    @Override
    public void clearValidationErrors() {

    }

    @Override
    public boolean hasConverter(Entity entity) {
        return true;
    }

    @Override
    public JobSummary getJobSummary() {
        return this.jobSummary;
    }

    private class Reader extends EntityRelationsParser {
        private RelationsManager manager;

        @Override
        protected void endEntities() {

        }

        @Override
        protected void startEntities() {

        }

        @Override
        protected void endRelations() {
            try {
                LOG.info("Relations: Drain: Starting...");
                this.manager.drain();
                LOG.info("Relations: Drain: Done!");

                this.manager.shutdown();
            } catch (InterruptedException e) {
                LOG.error("RelationsManager: Shutdown: Interrupted!", e);
            }
            finally {
                LOG.info("Relations: Done!");
            }
        }

        @Override
        protected void startRelations() {
            LOG.info("Relations: Starting...");
            this.manager = new RelationsManager(session.getRelationsRepository());
        }

        @Override
        protected void processEntity(Entity entity) {

        }

        @Override
        protected void processRelation(Relation relation) {
            if (relation == null || StringUtils.isEmpty(relation.getType())) {
                return;
            }

            String type = relation.getType();
            jobSummary.incrementProduced(type);
            this.manager.produce(new Relation(relation.get()));
            jobSummary.incrementCommitted(type);
        }

        public Reader() {

        }
    }
}
