/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.models.Conversion;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import org.apache.commons.collections.CollectionUtils;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonSerialize(include=JsonSerialize.Inclusion.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
@XmlRootElement
@XmlAccessorType(XmlAccessType.PROPERTY)
public class Method {
    public static final String FIELD_FUNCTION = "!";

    private static final String FIELD_NAME = "name";
    private String name;
    private String[] params;

    public Method(Map map) {
        this.name = (String) map.get(FIELD_NAME);
        this.params = getParamsFromMap(map);
    }

    private String[] getParamsFromMap(Map map) {
        Object o = map.get("params");
        if (o == null) {
            return null;
        }

        if (o instanceof List) {
            return (String[]) ((List) o).toArray(new String[]{});
        }

        return new String[]{(String) o};
    }

    private Object getParams(Map map) {
        return map.get("params");
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String[] getParams() {
        return params;
    }

    public void setParams(String[] params) {
        this.params = params;
    }

    public String getFirstParam() {
        return getParamAt(0);
    }

    public String getParamAt(int index) {
        return (this.params != null && this.params.length > index) ?
                this.params[index] :
                null;
    }

    @JsonIgnore
    public static Method from(String function) {
        if (!function.startsWith(FIELD_FUNCTION)) {
            return null;
        }

        return new Method(Collections.singletonMap("name", function.substring(1)));
    }
}
