/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.models;

import java.util.LinkedHashMap;
import java.util.Map;

public class JobSummary {
    private static final String CATEGORY_PROCESSED = "processed:";
    private static final String CATEGORY_PRODUCED = "produced:";
    private static final String CATEGORY_COMMITTED = "committed:";

    private Map<String, Integer> metrics;

    public JobSummary() {
        metrics = new LinkedHashMap<>();
    }

    public void incrementProcessed(String key) {
        increment(CATEGORY_PROCESSED + key);
    }

    public void incrementProduced(String key) {
        increment(CATEGORY_PRODUCED + key);
    }

    public void incrementCommitted(String key) {
        increment(CATEGORY_COMMITTED + key);
    }

    public void increment(String key) {
        if (!metrics.containsKey(key)) {
            metrics.put(key, 0);
        }

        Integer value = metrics.get(key);
        metrics.put(key, ++value);
    }

    public void summarize() {
        Integer produced = 0;
        Integer processed = 0;
        Integer committed = 0;

        for (Map.Entry<String, Integer> entry : metrics.entrySet()) {
            if (entry.getKey().startsWith(CATEGORY_PROCESSED)) {
                processed += entry.getValue();
            } else if (entry.getKey().startsWith(CATEGORY_COMMITTED)) {
                committed += entry.getValue();
            } else if (entry.getKey().startsWith(CATEGORY_PRODUCED)) {
                produced += entry.getValue();
            }
        }

        metrics.put(CATEGORY_COMMITTED, committed);
        metrics.put(CATEGORY_PROCESSED, processed);
        metrics.put(CATEGORY_PRODUCED, produced);
    }

    public Map<String, Integer> getMetrics() {
        summarize();
        return metrics;
    }
}
