/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.models;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonIgnoreProperties(ignoreUnknown=true)
@XmlRootElement
@XmlAccessorType(XmlAccessType.PROPERTY)
public class NodeContainer {
    List<Entity> entities;
    List<Relation> relations;

    public NodeContainer() {
        entities = new ArrayList<>();
        relations = new ArrayList<>();
    }

    public List<Entity> getEntities() {
        return entities;
    }

    @JsonProperty("entities")
    public void setEntitiesRaw(List<Map<String, Object>> maps) {
        entities = new ArrayList<>();
        for (Map<String, Object> entry : maps) {
            this.entities.add(new Entity(entry));
        }
    }

    public void setEntities(List<Entity> entities) {
        this.entities = entities;
    }

    public void setRelations(List<Relation> relations) {
        this.relations = relations;
    }

    public List<Relation> getRelations() { return this.relations; }

    @JsonProperty("relations")
    public void setRelationsRaw(List<Map<String, Object>> maps) {
        this.relations = new ArrayList<>();
        for (Map<String, Object> entry : maps) {
            this.relations.add(new Relation(entry));
        }
    }
}
