/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.pc;

import org.apache.atlas.pc.WorkItemBuilder;
import org.apache.atlas.pc.WorkItemManager;
import org.apache.atlas.tools.converter.EntityConverter;
import org.apache.atlas.tools.converter.RelationsRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.apache.atlas.tools.utils.PropertiesUtils.getAllFSElement;
import static org.apache.atlas.tools.utils.PropertiesUtils.getBatchSize;
import static org.apache.atlas.tools.utils.PropertiesUtils.getNumWorkers;

public class ConversionManager<Entity> extends WorkItemManager {
    private static final Logger LOG = LoggerFactory.getLogger(ConversionManager.class);

    public ConversionManager(RelationsRepository relationsRepository, EntityConverter converter) {
        this(new ConversionWorkItemBuilder(relationsRepository, converter, getAllFSElement(), getBatchSize()),
                getBatchSize(), getNumWorkers());
    }

    private ConversionManager(WorkItemBuilder builder, int batchSize, int numWorkers) {
        super(builder, "nav2atlas-entity", batchSize, numWorkers, true);
        LOG.info( String.format("ConversionManager: batchSize: %,d: numWorkers: %s", batchSize, numWorkers));
    }
}
