/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.pc;

import org.apache.atlas.pc.WorkItemBuilder;
import org.apache.atlas.tools.converter.EntityConverter;
import org.apache.atlas.tools.converter.RelationsRepository;
import org.apache.atlas.tools.models.Entity;

import java.util.concurrent.BlockingQueue;

public class ConversionWorkItemBuilder implements WorkItemBuilder<ConversionWorkItemConsumer, Entity> {
    private RelationsRepository relationsRepository;
    private final EntityConverter converter;
    private final int batchSize;
    private final boolean includeAllFsElement;

    public ConversionWorkItemBuilder(RelationsRepository relationsRepository, EntityConverter converter, boolean includeAllFsElement, int batchSize) {
        super();
        this.relationsRepository = relationsRepository;
        this.converter = converter;
        this.batchSize = batchSize;
        this.includeAllFsElement = includeAllFsElement;
    }

    @Override
    public ConversionWorkItemConsumer build(BlockingQueue<Entity> queue) {
        return new ConversionWorkItemConsumer(relationsRepository, converter, queue, includeAllFsElement, batchSize);
    }
}
