/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.tools.pc;

import org.apache.atlas.pc.WorkItemConsumer;
import org.apache.atlas.tools.converter.RelationsRepository;
import org.apache.atlas.tools.models.Relation;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;
import java.util.concurrent.BlockingQueue;

public class RelationsWorkItemConsumer extends WorkItemConsumer<Relation> {
    private static final Logger LOG = LoggerFactory.getLogger(RelationsWorkItemConsumer.class);

    private final RelationsRepository relationsRepository;
    private final int batchSize;
    private int currentIndex;

    public RelationsWorkItemConsumer(RelationsRepository relationsRepository, BlockingQueue<Relation> queue, int batchSize) {
        super(queue);
        this.relationsRepository = relationsRepository;
        this.batchSize = batchSize;
    }

    @Override
    protected void doCommit() {
        if (currentIndex % batchSize == 0) {
            LOG.info(String.format("Relations: Processed: %,d", currentIndex));
        }
    }

    @Override
    protected void processItem(Relation relation) {
        currentIndex++;
        if (StringUtils.isEmpty(relation.getType())) {
            return;
        }

        process(relation);

        commit();
    }

    private void process(Relation relation) {
        relationsRepository.add(relation);

        if (relation.containsKey("identity")) {
            addResult(relation.get("identity"));
        }
    }
}
