/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.tools.utils;

import org.apache.atlas.model.typedef.AtlasTypesDef;
import org.apache.atlas.type.AtlasType;
import org.apache.atlas.type.AtlasTypeRegistry;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class AtlasTypeRegistryUtils {
    private static final Logger LOG = LoggerFactory.getLogger(AtlasTypeRegistryUtils.class);

    public static AtlasTypeRegistry getAtlasTypeRegistry(AtlasTypesDef typesDef) {
        AtlasTypeRegistry ret = new AtlasTypeRegistry();
        AtlasTypeRegistry.AtlasTransientTypeRegistry ttr = null;
        boolean commit = false;

        try {
            ttr = ret.lockTypeRegistryForUpdate();
            ttr.addTypes(typesDef);

            commit = true;
        } catch (Exception ex) {
            LOG.error("Error initializing atlas AtlasTypeRegistry! {}", AtlasType.toJson(typesDef), ex);
        } finally {
            if (ttr != null) {
                ret.releaseTypeRegistryForUpdate(ttr, commit);
            }
        }

        return ret;
    }
}
