/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.utils;

import org.apache.atlas.tools.models.MultiNodeContainer;
import org.apache.atlas.type.AtlasType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ClassUtils {
    private static final Logger LOG = LoggerFactory.getLogger(ClassUtils.class);

    public static MultiNodeContainer getObjectFromType(String className) {
        Object instance = createInstance(className);
        String entityJson = JsonUtils.to(instance);
        return AtlasType.fromJson(entityJson, MultiNodeContainer.class);
    }

    public static Object createInstance(String className) {
        try {
            Class clazz = getClassFromString(className);
            return clazz.newInstance();
        } catch (InstantiationException e) {
            LOG.error( "createInstance", e);
            return null;
        } catch (IllegalAccessException e) {
            LOG.error( "createInstance", e);
            return null;
        }
    }

    public static Class getClassFromString(String className) {
        try {
            return Class.forName(className);
        } catch (ClassNotFoundException e) {
            LOG.error( String.format("Class: %s: Not found!", className), e);
            return null;
        }
    }
}
