/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.utils;

import com.fasterxml.jackson.core.JsonFactory;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.MappingJsonFactory;
import org.apache.atlas.model.instance.AtlasEntity;
import org.apache.atlas.tools.converter.EntityRelationsWriter;

import java.io.IOException;
import java.io.OutputStream;

public class EntityRelationsJsonWriter implements EntityRelationsWriter {
    private static final JsonFactory jsonFactory = new MappingJsonFactory();
    JsonGenerator jsonGenerator;

    public EntityRelationsJsonWriter(OutputStream stream) throws IOException {
        jsonGenerator = jsonFactory.createGenerator(stream);
        jsonGenerator.configure(JsonGenerator.Feature.AUTO_CLOSE_TARGET, false);
        jsonGenerator.writeStartObject();
    }

    @Override
    public void startEntities() throws IOException {
        jsonGenerator.writeArrayFieldStart("entities");
    }

    @Override
    public void writeEntity(String id, Object o) throws IOException {
        jsonGenerator.writeObject(o);
    }

    @Override
    public void endEntities() throws IOException {
        jsonGenerator.writeEndArray();
    }

    @Override
    public void startRelations() throws IOException {
        jsonGenerator.writeArrayFieldStart("relations");
    }

    @Override
    public void writeRelation(String id, Object o) throws IOException {
        jsonGenerator.writeObject(o);
    }

    @Override
    public void endRelations() throws IOException {
        jsonGenerator.writeEndArray();
    }

    @Override
    public void writeEntry(String name, String payload) throws IOException {
        jsonGenerator.writeObject(payload);
    }

    @Override
    public void flush() {

    }

    @Override
    public void close() throws IOException {
        if (jsonGenerator == null) {
            return;
        }
        jsonGenerator.writeEndObject();
        flush();
    }

    @Override
    public void flushAndClose() throws IOException {
        jsonGenerator.flush();
        jsonGenerator.close();
    }

    @Override
    public void setStreamSize(long streamSize) {

    }
}
