/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.tools.utils;

import org.apache.atlas.type.AtlasType;
import org.apache.atlas.utils.AtlasJson;
import org.apache.commons.lang.StringUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ConcurrentMap;

import static org.apache.atlas.tools.models.Conversion.Constants.PADDING_SIZE;

public class MapStoringJsonList extends MapStoringList {
    public MapStoringJsonList(ConcurrentMap<String, String> map) {
        super(map);
    }

    @Override
    public void addList(String key, List<String> elementsToBeAdded) {
        this.map.put(key, AtlasJson.toJson(elementsToBeAdded));
    }

    @Override
    public List<String> get(String key) {
        if (StringUtils.isEmpty(key) || !map.containsKey(key)) {
            return null;
        }

        String jsonStr = map.get(key);
        jsonStr = jsonStr.replaceAll(" +", "\",\"").replace("[", "[\"").replace("]", "\"]");
        if (jsonStr.equals("[\"\"]")) {
            return null;
        }

        return AtlasType.fromJson(jsonStr, List.class);
    }

    @Override
    public int size() {
        return this.map.size();
    }
}
