/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.tools.utils.EntityRelationsJsonWriter;
import org.testng.annotations.Test;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;

import static org.testng.Assert.assertTrue;

public class EntitiesRelationsWriterTest {
    @Test
    public void readRel() throws IOException {
        OutputStream bos = new ByteArrayOutputStream();
        EntityRelationsJsonWriter erw = new EntityRelationsJsonWriter(bos);

        erw.startEntities();
        erw.writeEntity("-1", "{ \"a\": \"b\" }");
        erw.writeEntity("-2", "{ \"c\": \"d\" }");
        erw.endEntities();

        erw.startRelations();
        erw.writeRelation("-3", "{ \"v\": \"w\" }");
        erw.writeRelation("-4", "{ \"x\": \"y\" }");
        erw.endRelations();

        erw.close();

        String outputJson = bos.toString();
        assertTrue(outputJson.contains("a"));
        assertTrue(outputJson.contains("b"));
        assertTrue(outputJson.contains("c"));
        assertTrue(outputJson.contains("d"));
        assertTrue(outputJson.contains("v"));
        assertTrue(outputJson.contains("w"));
        assertTrue(outputJson.contains("x"));
        assertTrue(outputJson.contains("y"));
    }
}
