/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.model.instance.AtlasEntity;
import org.apache.atlas.tools.BaseTest;
import org.testng.annotations.Test;

import java.util.List;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertTrue;

public class HdfsConversionTest extends BaseTest {
    @Test(expectedExceptions = ConversionException.class)
    public void unknownTypeThrowsException() throws Exception {
        converter.process("hdfs/file-XXX.json");
    }
    
    @Test
    public void filePermissions() throws Exception {
        AtlasEntity expected = readObjectFromJson("hdfs", "file-permissions-atlas", AtlasEntity.class);
        List<AtlasEntity.AtlasEntityWithExtInfo> actualArray = convert("hdfs", "file");
        AtlasEntity actual = getFirstEntity(actualArray);

        assertEqualsEntity(actual, expected);
    }

    @Test
    void fs_permissionsConversion() {
        assertEquals(ConversionMethods.getPermissionOrdinal("rwx"), "ALL");
        assertEquals(ConversionMethods.getPermissionOrdinal("rw-"), "READ_WRITE");
        assertEquals(ConversionMethods.getPermissionOrdinal("r-x"), "READ_EXECUTE");
        assertEquals(ConversionMethods.getPermissionOrdinal("---"), "NONE");
        assertEquals(ConversionMethods.getPermissionOrdinal("--x"), "EXECUTE");
        assertEquals(ConversionMethods.getPermissionOrdinal("-"), "NONE");
        assertEquals(ConversionMethods.getPermissionOrdinal("???"), "NONE");
    }

    @Test
    public void directoryFile() throws Exception {
        AtlasEntity.AtlasEntitiesWithExtInfo expected = readObjectFromJson("hdfs", "directory-file-atlas", AtlasEntity.AtlasEntitiesWithExtInfo.class);
        List<AtlasEntity.AtlasEntityWithExtInfo> actual = convert("hdfs", "directory-file");

        assertNotNull(actual);
        assertEquals(actual.size(), expected.getEntities().size());

        assertEqualsEntity(getEntityAt(actual, 0), expected.getEntities().get(0));
        assertEqualsEntity(getEntityAt(actual, 1), expected.getEntities().get(1));
    }

    @Test
    public void fileWithUnmappedKeys() throws Exception {
        AtlasEntity expected = readObjectFromJson("hdfs", "file-extra-keys-atlas", AtlasEntity.class);
        List<AtlasEntity.AtlasEntityWithExtInfo> actualArray = convert("hdfs", "file-extra-keys");
        AtlasEntity actual = getFirstEntity(actualArray);

        assertEqualsEntity(actual, expected);
    }
}
