/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.model.instance.AtlasEntity;
import org.apache.atlas.tools.BaseTest;
import org.apache.atlas.tools.converter.ConversionException;
import org.apache.atlas.tools.converter.Converter;
import org.apache.atlas.tools.models.NodeContainer;
import org.apache.atlas.type.AtlasType;
import org.testng.annotations.Test;

import java.io.IOException;
import java.util.List;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertTrue;

public class NodeContainerToAtlasEntityConverterTest extends BaseTest {
    @Test
    public void hdfsFile() throws IOException, ConversionException {
        AtlasEntity expected = readObjectFromJson("hdfs", "file-atlas", AtlasEntity.class);
        List<AtlasEntity.AtlasEntityWithExtInfo> entitiesWithExtInfo = convert("hdfs", "file");

        assertNotNull(entitiesWithExtInfo);
        assertEquals(entitiesWithExtInfo.size(), 1);
        assertEquals(getFirstEntity(entitiesWithExtInfo).getGuid(), "e7d578c9-5978-43d9-aacd-000000000164");
        assertEquals(getFirstEntity(entitiesWithExtInfo).getStatus(), AtlasEntity.Status.ACTIVE);
        assertEquals(getFirstEntity(entitiesWithExtInfo).getAttribute("clusterName"), "cm");
    }

    @Test
    public void conversionToJson() throws IOException {
        NodeContainer container = AtlasType.fromJson(readString("mixed", "default-db"), NodeContainer.class);

        assertNotNull(container);

        String json = AtlasType.toJson(container);

        assertNotNull(json);
        assertFalse(json.contains("{}"));
    }

}
