/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.tools.converter;

import org.apache.atlas.model.instance.AtlasEntity;
import org.apache.atlas.tools.BaseTest;
import org.apache.atlas.tools.models.Conversion.Constants;
import org.apache.atlas.tools.models.Session;
import org.apache.commons.lang.StringUtils;
import org.jetbrains.annotations.NotNull;
import org.testng.annotations.Test;

import java.util.Collections;
import java.util.Date;

import static org.testng.Assert.assertEquals;

public class ProcessQualifiedNameGeneratorTest extends BaseTest {
    @Test
    public void onlyInputPresent() {
        session.setupUniqueNameValidator();

        String fallbackId = "0x0";
        session.getUniqueNameValidator().register(getAtlasEntity("1", "t1", 100));
        String s = ProcessQualifiedNameGenerator.toProcessQualifiedName(session, fallbackId, Collections.singletonList("1"), null, "2222");

        assertEquals(s, "cm:2222:t1:100");
    }

    @Test
    public void inputsOutputsBothPresent() {
        session.setupUniqueNameValidator();

        String fallbackId = "0x0";
        session.getUniqueNameValidator().register(getAtlasEntity("1", "t1", 100));
        session.getUniqueNameValidator().register(getAtlasEntity("2", "t2", 200));
        String s = ProcessQualifiedNameGenerator.toProcessQualifiedName(session,
                fallbackId, Collections.singletonList("1"), Collections.singletonList("2"), "1111");

        assertEquals(s, "cm:1111:t1:100->t2:200");
    }

    @NotNull
    private AtlasEntity getAtlasEntity(String guid, String qname, int date) {
        AtlasEntity t1 = new AtlasEntity();
        t1.setTypeName("hive_table");
        t1.setGuid(ConversionMethods.getEntityGuid(session, (String) guid));
        t1.setCreateTime(new Date(date));
        t1.setAttribute("qualifiedName", qname);
        return t1;
    }
}
