/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.tools.BaseTest;
import org.apache.atlas.tools.models.NodeContainer;
import org.apache.atlas.tools.models.Relation;
import org.apache.atlas.tools.utils.JsonUtils;
import org.apache.atlas.type.AtlasType;
import org.testng.annotations.Test;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import static org.testng.Assert.assertEquals;

public class RelationsRepositoryTest extends BaseTest {

    private RelationsRepository relationsRepository;

    @Test
    public void relationshipRepositoryCreation() throws IOException {
        String json = readString("relationships", "hive-db-table");
        relationsRepository = createRelationsRepository(AtlasType.fromJson(json, NodeContainer.class));

        assertEquals(relationsRepository.getInstancesOfSize(), 1);

        assertEquals(relationsRepository.getDataFlowInputsSize(), 1);
        assertEquals(relationsRepository.getDataFlowOutputsSize(), 1);

        assertEquals(relationsRepository.getControlFlowInputsSize(), 1);
        assertEquals(relationsRepository.getControlFlowOutputsSize(), 1);

        assertEquals(relationsRepository.getChildParentSize(), 1);
        assertEquals(relationsRepository.getParentChildSize(), 1);
    }

    @Test(dependsOnMethods = "relationshipRepositoryCreation")
    public void templateFetch() {
        assertEquals(relationsRepository.getTemplateId(JsonUtils.getPaddedString("59546")), JsonUtils.getPaddedString("59537"));
    }

    @Test(dependsOnMethods = "relationshipRepositoryCreation")
    public void simpleInputsOutputs() {
        String item2043 = JsonUtils.getPaddedString("2043");
        String[] inputs = new ArrayList<String>(relationsRepository.getInputs(item2043)).toArray(new String[]{});
        String item2041 = JsonUtils.getPaddedString("2041");
        String[] outputs = new ArrayList<String>(relationsRepository.getOutputs(item2041)).toArray(new String[]{});

        assertEquals(inputs, new String[]{item2041, item2041});
        assertEquals(outputs, new String[]{item2043, item2043});
    }

    @Test
    public void inferredInputsOutputs() throws IOException {
        String json = readString("relationships", "stocks-relations");
        RelationsRepository rr  = createRelationsRepository(AtlasType.fromJson(json, NodeContainer.class));

        assertEquals(rr.getInferredInputs(JsonUtils.getPaddedString("64")), Collections.singletonList(JsonUtils.getPaddedString("74")));
        assertEquals(rr.getInferredOutputs(JsonUtils.getPaddedString("64")), Collections.singletonList(JsonUtils.getPaddedString("82")));
    }

    private RelationsRepository createRelationsRepository(NodeContainer nodeContainer) {
        RelationsRepository rr = new RelationsRepository(session);
        for (Relation relation : nodeContainer.getRelations()) {
            rr.add(relation);
        }

        return rr;
    }
}
