/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.tools.BaseTest;
import org.apache.atlas.tools.models.NodeContainer;
import org.apache.atlas.tools.models.Relation;
import org.apache.atlas.tools.utils.JsonUtils;
import org.apache.atlas.type.AtlasType;
import org.testng.annotations.Test;

import java.io.IOException;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertTrue;

public class RelationshipReaderTest extends BaseTest {
    @Test
    public void readJson() throws IOException {
        String json = readString("relationships", "hive-db-table");
        NodeContainer nodeContainer = AtlasType.fromJson(json, NodeContainer.class);

        assertNotNull(nodeContainer);
        assertNotNull(nodeContainer.getEntities());
        assertNotNull(nodeContainer.getRelations());

        assertEquals(nodeContainer.getEntities().size(), 0);
        assertEquals(nodeContainer.getRelations().size(), 4);
    }

    @Test
    public void retrieveRelations() throws IOException {
        String json = readString("relationships", "hive-db-table");
        NodeContainer nodeContainer = AtlasType.fromJson(json, NodeContainer.class);

        boolean foundInstanceOf = false;
        boolean foundDataFlow = false;
        boolean foundControlFlow = false;
        boolean foundParentChild = false;
        for (Relation nc : nodeContainer.getRelations()) {
            String type = nc.getType();
            if (type.equals(Relation.RELATION_TYPE_INSTANCE_OF)) {
                assertEquals(Relation.InstanceOf.getTemplate(nc), JsonUtils.getPaddedString("59537"));
                foundInstanceOf = true;
            } else if (type.equals(Relation.RELATION_TYPE_DATA_FLOW)) {
                assertEquals(Relation.DataFlow.getSources(nc).toArray(new String[]{}), new String[] {JsonUtils.getPaddedString("2041")});
                assertEquals(Relation.DataFlow.getTargets(nc).toArray(new String[]{}), new String[] {JsonUtils.getPaddedString("2043")});
                foundDataFlow = true;
            } else if (type.equals(Relation.RELATION_TYPE_PARENT_CHILD)) {
                assertEquals(Relation.ParentChild.getParent(nc), JsonUtils.getPaddedString("24"));
                assertEquals(Relation.ParentChild.getChildren(nc).toArray(new String[]{}), new String[] {JsonUtils.getPaddedString("25")});
                foundParentChild = true;
            } else if (type.equals(Relation.RELATION_TYPE_CONTROL_FLOW)) {
                assertEquals(Relation.ControlFlow.getSources(nc).toArray(new String[]{}), new String[] {JsonUtils.getPaddedString("81")});
                assertEquals(Relation.ControlFlow.getTargets(nc).toArray(new String[]{}), new String[] {JsonUtils.getPaddedString("59554")});
                foundControlFlow = true;
            }
        }

        assertTrue(foundInstanceOf, "instanceOf");
        assertTrue(foundDataFlow, "dataFlow");
        assertTrue(foundControlFlow, "controlFlow");
        assertTrue(foundParentChild, "parentChild");
    }
}
