/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.model.typedef.AtlasEntityDef;
import org.apache.atlas.model.typedef.AtlasTypesDef;
import org.apache.atlas.tools.BaseTest;
import org.json.JSONException;
import org.testng.Assert;
import org.testng.annotations.BeforeTest;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import java.io.IOException;
import java.util.List;
import java.util.stream.Collectors;

public class S3Test extends BaseTest {
    private String SUB_DIR = "s3";

    @BeforeTest
    public void assertEntityTypes(){
        List<AtlasEntityDef> entityDefs = session.getAtlasTypesDef().getEntityDefs();
        List<String> names = entityDefs.stream().map(AtlasEntityDef::getName).collect(Collectors.toList());
        Assert.assertTrue(names.contains("aws_s3_v2_bucket"));
    }

    @DataProvider(name = "data")
    private Object[][] comparisonQueriesProvider() {
        return new Object[][]{
                {"s3-bucket"},
                {"s3-object-file"},
                {"s3-object-directory"}
        };
    }
    @Test(dataProvider = "data")
    public void verify(String file) throws ConversionException, JSONException, IOException {
        assertEntityWithFileInput(SUB_DIR, file);
    }
}
