/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.tools.converter;

import org.apache.atlas.tools.BaseTest;
import org.apache.atlas.tools.models.Conversion.Specs;
import org.apache.atlas.type.AtlasType;
import org.testng.annotations.Test;

import java.io.IOException;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertTrue;

public class SpecReaderTest extends BaseTest {
    @Test
    public void readSpecs() throws IOException {
        Specs specs = AtlasType.fromJson(readString("hdfs", "hdfs-spec-test"), Specs.class);

        assertNotNull(specs);
        assertEquals(specs.size(), 3);
        assertEquals(specs.getAtlasType(), "hdfs_file");

        String identity = "identity";
        assertEquals(specs.getSpec(identity).get(0).getFrom(), identity);
        assertEquals(specs.getSpec(identity).get(0).getTo(), "guid");

        String originalName = "originalName";
        assertEquals(specs.getSpec(originalName).get(0).getFrom(), originalName);
        assertEquals(specs.getSpec(originalName).get(0).getTo(), "attributes.name");
        assertTrue(specs.getSpec(originalName).get(0).isAttr());

        String sourceId = "sourceId";
        assertEquals(specs.getSpec(sourceId).get(0).getFrom(), sourceId);
        assertEquals(specs.getSpec(sourceId).get(0).getTo(), "attributes.clusterName");
        assertTrue(specs.getSpec(sourceId).get(0).isAttr());
        assertEquals(specs.getSpec(sourceId).get(0).getMethods()[0].getName(), "prefix");
    }
}
